# KIKUSUI Regulated Power Supply 

Implementation of the commanding and monitoring of the KIKUSUI PMX-A power supplies.  

## Reference Documents

- User's Manual Regulated DC Power Supply - PMX Series (PMX18-2A, PMX18-5A, PMX35-1A, PMX35-3A, PMX70-1A, PMX110-0.6A, 
  PM250-0-0.25A, PMX350-0.2A, PMX500-0.1A)
- Communication Interface Manual